@@ -120,6 +120,7 @@ class UdpSession(object):
                 cls.handle(received.decode().split(','))
                 time.sleep(1)
             except Exception as e:
+                print('get stack ', e)
                 logging.debug(e, extra={'id': 'WA914'}, exc_info=True)
 
     @classmethod
@@ -145,10 +146,11 @@ class UdpSession(object):
             for stack in traceback.extract_stack(frame):
                 line = stack[0]
                 line_num = stack[1]
+                method_name = stack[2]
 
                 if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
                     continue
-                data += '{} (line {})\n'.format(line, line_num)
+                data += '{} ({}:{})\n'.format(method_name, line, line_num)
 
             datas.append(data)
 
@@ -171,10 +173,11 @@ class UdpSession(object):
                 for stack in traceback.extract_stack(frame):
                     line = stack[0]
                     line_num = stack[1]
+                    method_name = stack[2]
 
                     if line.find('whatap/trace') > -1:
                         continue
-                    data += '{} (line {})\n'.format(line, line_num)
+                    data += '{} ({}:{})\n'.format(method_name, line, line_num)
 
                 datas.append(data)
 
